Module model

Module model 

Model definitions for HTTP client

Re-exports

pub use access_log::*;
pub use account::*;
pub use affiliate::*;
pub use announcement::*;
pub use api_key::*;
pub use beneficiary::*;
pub use block_trade::*;
pub use book::*;
pub use combo::*;
pub use currency::*;
pub use custody::*;
pub use deposit::*;
pub use email_settings::*;
pub use fee::*;
pub use funding::*;
pub use index::*;
pub use instrument::*;
pub use margin_model::*;
pub use mass_quote::*;
pub use option::*;
pub use order::*;
pub use other::*;
pub use portfolio_simulation::*;
pub use position::*;
pub use request::*;
pub use response::*;
pub use self_trading::*;
pub use settlement::*;
pub use ticker::*;
pub use trade::*;
pub use trading_products::*;
pub use tradingview::*;
pub use transaction::*;
pub use transfer::*;
pub use trigger::*;
pub use types::*;
pub use user_lock::*;
pub use wallet::*;
pub use withdrawal::*;

Modules

access_log
Access log models for account history Access log models for Deribit API
account
Account-related models and structures
affiliate
Affiliate program models Affiliate program models for Deribit API
announcement
Announcement models Announcement models for Deribit API
api_key
API key management models API key management models and types
beneficiary
Address beneficiary models for wallet endpoints Address beneficiary models for wallet endpoints
block_trade
Block trade models Block trade models for the Deribit API.
book
Order book models
combo
Combo books models for multi-leg instruments Combo books models for Deribit API
currency
Currency and expiration models
custody
Custody account models Custody account models for Deribit API
deposit
Deposit-related models
email_settings
Email settings models Email settings models for Deribit API
fee
Fee calculation and structure models
funding
Funding rate models
index
Index price models
instrument
Instrument definition models
margin_model
Margin model configuration Margin model types for Deribit API
mass_quote
Mass quote models
option
Option contract models and types
order
Order models and types
other
Other miscellaneous models
portfolio_simulation
Portfolio simulation models Portfolio simulation models for Deribit API
position
Position models
request
Request models and structures
response
Response models and structures
self_trading
Self-trading configuration models Self-trading configuration models for Deribit API
settlement
Settlement models
ticker
Ticker data models
trade
Trade execution models
trading_products
Trading products configuration Trading products models for Deribit API
tradingview
TradingView chart models
transaction
Transaction log models
transfer
Transfer models
trigger
Trigger models
types
Common type definitions HTTP-specific types and models
user_lock
User lock models User lock models for Deribit API
wallet
Wallet models for deposit addresses and address book Wallet-related models for deposit addresses and address book operations.
withdrawal
Withdrawal models