pub struct ApiKeyInfo {
pub id: u64,
pub client_id: String,
pub client_secret: String,
pub name: String,
pub max_scope: String,
pub enabled: bool,
pub default: bool,
pub timestamp: u64,
pub enabled_features: Vec<String>,
pub ip_whitelist: Option<Vec<String>>,
pub public_key: Option<String>,
}Expand description
API key information returned by API key management endpoints.
Contains all details about an API key including credentials, permissions, and configuration.
Fields
id: u64Unique identifier for the API key
client_id: StringClient identifier used for authentication
client_secret: StringClient secret or MD5 fingerprint of public key used for authentication
name: StringAPI key name that can be displayed in transaction log
max_scope: StringDescribes maximal access for tokens generated with this key.
Possible values include combinations of:
trade:[read, read_write, none]wallet:[read, read_write, none]account:[read, read_write, none]block_trade:[read, read_write, none]block_rfq:[read, read_write, none]
enabled: boolWhether the API key is enabled and can be used for authentication
default: boolWhether this API key is the default (deprecated, will be removed)
timestamp: u64Timestamp when the key was created or last modified, in milliseconds since Unix epoch
enabled_features: Vec<String>List of enabled advanced on-key features.
Available options:
restricted_block_trades: Limit block_trade read scope to trades made with this keyblock_trade_approval: Block trades require additional user approval
ip_whitelist: Option<Vec<String>>List of IP addresses whitelisted for this key
public_key: Option<String>PEM encoded public key (Ed25519/RSA) used for asymmetric signatures