pub struct EditApiKeyRequest {
pub id: u64,
pub max_scope: String,
pub name: Option<String>,
pub enabled: Option<bool>,
pub enabled_features: Option<Vec<String>>,
pub ip_whitelist: Option<Vec<String>>,
}Expand description
Request parameters for editing an existing API key.
At least one optional parameter must be provided along with the required fields.
Example
use deribit_http::model::EditApiKeyRequest;
let request = EditApiKeyRequest {
id: 123,
max_scope: "account:read_write trade:read_write".to_string(),
name: Some("updated_key_name".to_string()),
..Default::default()
};Fields
id: u64ID of the API key to edit
max_scope: StringDescribes maximal access for tokens generated with this key.
Required. Possible values include combinations of:
trade:[read, read_write, none]wallet:[read, read_write, none]account:[read, read_write, none]block_trade:[read, read_write, none]
name: Option<String>Name of key (only letters, numbers and underscores; max 16 characters)
enabled: Option<bool>Enable or disable the API key
enabled_features: Option<Vec<String>>List of enabled advanced on-key features
ip_whitelist: Option<Vec<String>>List of IP addresses to whitelist for this key