SaveAddressBeneficiaryRequest

Struct SaveAddressBeneficiaryRequest 

pub struct SaveAddressBeneficiaryRequest {
Show 13 fields pub currency: String, pub address: String, pub tag: Option<String>, pub agreed: bool, pub personal: bool, pub unhosted: bool, pub beneficiary_vasp_name: String, pub beneficiary_vasp_did: String, pub beneficiary_vasp_website: Option<String>, pub beneficiary_first_name: Option<String>, pub beneficiary_last_name: Option<String>, pub beneficiary_company_name: Option<String>, pub beneficiary_address: String,
}
Request parameters for saving an address beneficiary.

All fields required by the API are marked as non-optional. Optional fields use Option<T>.

Fields

currency: String

Currency symbol (required)

address: String

Address in currency format (required)

tag: Option<String>

Tag for XRP addresses (optional)

agreed: bool

User agrees to share information with third parties (required)

personal: bool

Whether this is a personal wallet (required)

unhosted: bool

Whether the address belongs to an unhosted wallet (required)

beneficiary_vasp_name: String

Name of the beneficiary VASP (required)

beneficiary_vasp_did: String

DID of the beneficiary VASP (required)

beneficiary_vasp_website: Option<String>

Website of the beneficiary VASP (optional, required if VASP not in known list)

beneficiary_first_name: Option<String>

First name of the beneficiary (optional, for persons)

beneficiary_last_name: Option<String>

Last name of the beneficiary (optional, for persons)

beneficiary_company_name: Option<String>

Company name of the beneficiary (optional, for companies)

beneficiary_address: String

Geographical address of the beneficiary (required)