pub struct ComboTrade {
pub instrument_name: String,
pub amount: Option<f64>,
pub direction: String,
}Expand description
Trade input for creating a combo
Used as input to the create_combo endpoint to specify
the instruments and directions for each leg.
Fields
instrument_name: StringInstrument name for this trade
amount: Option<f64>Trade amount (optional). For perpetual and inverse futures the amount is in USD units. For options and linear futures it is the underlying base currency coin.
direction: StringDirection of trade from the maker perspective: “buy” or “sell”
Implementations
Sourceimpl ComboTrade
impl ComboTrade
Sourcepub fn new(
instrument_name: impl Into<String>,
direction: impl Into<String>,
amount: Option<f64>,
) -> Self
pub fn new( instrument_name: impl Into<String>, direction: impl Into<String>, amount: Option<f64>, ) -> Self
Creates a new combo trade
Arguments
instrument_name- The instrument identifierdirection- Trade direction (“buy” or “sell”)amount- Optional trade amount