pub struct LegInput {
pub instrument_name: String,
pub amount: f64,
pub direction: String,
}Expand description
Leg input for get_leg_prices endpoint
Specifies the parameters for calculating individual leg prices.
Fields
instrument_name: StringInstrument name for this leg
amount: f64Trade amount. For perpetual and inverse futures the amount is in USD units. For options and linear futures it is the underlying base currency coin.
direction: StringDirection of the leg: “buy” or “sell”
Implementations