pub struct LegPricesResponse {
pub amount: f64,
pub legs: Vec<LegPrice>,
}Expand description
Response from get_leg_prices endpoint
Contains the calculated leg prices for a combo structure.
Fields
amount: f64This value multiplied by the ratio of a leg gives trade size on that leg
legs: Vec<LegPrice>List of leg prices
Implementations