Module wallet

Module wallet 

Wallet request models for withdrawals and address book Request models for wallet operations.

Structs

AddToAddressBookRequest
Request parameters for adding an address to the address book.
UpdateInAddressBookRequest
Request parameters for updating an address in the address book.
WithdrawRequest
Request parameters for withdrawing funds.