MarginsResponse

Struct MarginsResponse 

pub struct MarginsResponse {
    pub buy: f64,
    pub sell: f64,
    pub min_price: f64,
    pub max_price: f64,
}
Response from the get_margins endpoint

Contains margin requirements for a hypothetical order on a given instrument. This is useful for estimating margin requirements before placing an order.

Fields

buy: f64

Margin required when buying

sell: f64

Margin required when selling

min_price: f64

The minimum price for the future. Any sell orders submitted lower than this price will be clamped to this minimum.

max_price: f64

The maximum price for the future. Any buy orders submitted higher than this price will be clamped to this maximum.