pub struct AccountInfo {Show 14 fields
pub id: u64,
pub email: String,
pub system_name: Option<String>,
pub username: Option<String>,
pub block_rfq_self_match_prevention: Option<bool>,
pub creation_timestamp: Option<u64>,
pub account_type: Option<String>,
pub referrer_id: Option<String>,
pub login_enabled: Option<bool>,
pub security_keys_enabled: Option<bool>,
pub mmp_enabled: Option<bool>,
pub interuser_transfers_enabled: Option<bool>,
pub self_trading_reject_mode: Option<String>,
pub self_trading_extended_to_subaccounts: Option<bool>,
}Expand description
Shared account-level fields returned by both singular and plural account summary endpoints.
Fields
id: u64Account id
email: StringUser email
system_name: Option<String>System generated user nickname
username: Option<String>Account name (given by user)
block_rfq_self_match_prevention: Option<bool>When Block RFQ Self Match Prevention is enabled
creation_timestamp: Option<u64>Time at which the account was created (milliseconds since the Unix epoch)
account_type: Option<String>Account type
referrer_id: Option<String>Optional identifier of the referrer
login_enabled: Option<bool>Whether account is loginable using email and password
security_keys_enabled: Option<bool>Whether Security Key authentication is enabled
mmp_enabled: Option<bool>Whether MMP is enabled
interuser_transfers_enabled: Option<bool>true when the inter-user transfers are enabled for user
self_trading_reject_mode: Option<String>Self trading rejection behavior - reject_taker or cancel_maker
self_trading_extended_to_subaccounts: Option<bool>true if self trading rejection behavior is applied to trades between subaccounts