Module time_compat

Module time_compat 

Cross-platform time utilities for native and WASM targets Cross-platform time utilities for native and WASM targets

This module provides unified Instant, SystemTime, and UNIX_EPOCH types that work across both native (std::time) and WASM (web_time) targets.

Structs

Instant
A measurement of a monotonically nondecreasing clock. Opaque and useful only with Duration.
SystemTime
A measurement of the system clock, useful for talking to external entities like the file system or other processes.

Constants

UNIX_EPOCH
An anchor in time which can be used to create new SystemTime instances or learn about where in time a SystemTime lies.