pub struct SaveAddressBeneficiaryRequest {Show 13 fields
pub currency: String,
pub address: String,
pub tag: Option<String>,
pub agreed: bool,
pub personal: bool,
pub unhosted: bool,
pub beneficiary_vasp_name: String,
pub beneficiary_vasp_did: String,
pub beneficiary_vasp_website: Option<String>,
pub beneficiary_first_name: Option<String>,
pub beneficiary_last_name: Option<String>,
pub beneficiary_company_name: Option<String>,
pub beneficiary_address: String,
}Expand description
Request parameters for saving an address beneficiary.
All fields required by the API are marked as non-optional.
Optional fields use Option<T>.
Fields
currency: StringCurrency symbol (required)
address: StringAddress in currency format (required)
tag: Option<String>Tag for XRP addresses (optional)
agreed: boolUser agrees to share information with third parties (required)
personal: boolWhether this is a personal wallet (required)
unhosted: boolWhether the address belongs to an unhosted wallet (required)
beneficiary_vasp_name: StringName of the beneficiary VASP (required)
beneficiary_vasp_did: StringDID of the beneficiary VASP (required)
beneficiary_vasp_website: Option<String>Website of the beneficiary VASP (optional, required if VASP not in known list)
beneficiary_first_name: Option<String>First name of the beneficiary (optional, for persons)
beneficiary_last_name: Option<String>Last name of the beneficiary (optional, for persons)
beneficiary_company_name: Option<String>Company name of the beneficiary (optional, for companies)
beneficiary_address: StringGeographical address of the beneficiary (required)