Wallet request models for withdrawals and address book Request models for wallet operations.
Structs
- AddTo
Address Book Request - Request parameters for adding an address to the address book.
- Update
InAddress Book Request - Request parameters for updating an address in the address book.
- Withdraw
Request - Request parameters for withdrawing funds.