pub struct MarginsResponse {
pub buy: f64,
pub sell: f64,
pub min_price: f64,
pub max_price: f64,
}Expand description
Response from the get_margins endpoint
Contains margin requirements for a hypothetical order on a given instrument. This is useful for estimating margin requirements before placing an order.
Fields
buy: f64Margin required when buying
sell: f64Margin required when selling
min_price: f64The minimum price for the future. Any sell orders submitted lower than this price will be clamped to this minimum.
max_price: f64The maximum price for the future. Any buy orders submitted higher than this price will be clamped to this maximum.